/* ui-version: 5 (do not change when modifying theme for yourself) */
/* Fonts */
@if not(global-variable-exists(font-base-size)) {
  $font-base-size: 16px !global;
}

@if not(global-variable-exists(font-mono)) {
  $font-mono: monospace !global;
}

@if not(global-variable-exists(font-sans)) {
  $font-sans: sans-serif !global;
}

@if not(global-variable-exists(font-family-default)) {
  $font-family-default: $font-sans !global;
}

body {
  background-color: white !important;
  color: black;
  overflow-x: auto;
  overflow-y: hidden;
  word-break: break-word;
  word-wrap: break-word;

  font-size: $font-base-size;
  font-family: $font-family-default;
  margin: 0 0 0 0;
  text-align: left;
}

.search_coloring *::selection {
    background-color: #00ddff;
}

blockquote {
    margin: 0px 10px 0px 10px;
    padding-left: 15px;
    padding-right: 15px;
    border: 0;
    /*border-left: 3px #aaa solid;*/
    border-left: #5555EE solid 0.2em;
    color: #5555ee;
}

blockquote.level_001 {
  margin-bottom: 0px;
  margin-top: 0px;
}

blockquote > blockquote {
    border-left: #425c78 solid 0.2em;
    color: #425c78;
    margin-left: 0;
}

blockquote > blockquote > blockquote {
    border-left: #729fcf solid 0.2em;
    color: #729fcf;
}

blockquote > blockquote > blockquote > blockquote {
    border-left: #5555EE solid 0.2em;
    color: #5555ee;
}

blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #425c78 solid 0.2em;
    color: #425c78;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #729fcf solid 0.2em;
    color: #729fcf;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #5555EE solid 0.2em;
    color: #5555ee;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #425c78 solid 0.2em;
    color: #425c78;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #729fcf solid 0.2em;
    color: #729fcf;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #5555EE solid 0.2em;
    color: #5555ee;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #425c78 solid 0.2em;
    color: #425c78;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #729fcf solid 0.2em;
    color: #729fcf;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #5555EE solid 0.2em;
    color: #5555ee;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #425c78 solid 0.2em;
    color: #425c78;
}

blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote > blockquote {
    border-left: #729fcf solid 0.2em;
    color: #729fcf;
}

